==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-mount/translations/mount_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>可移动媒体管理器</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>可移动媒体设置</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="26"/>
        <source>When a device is connected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>弹出菜单</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>显示信息</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>什么都不做</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt; 已连接。</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt; 已移除。</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>可移动媒体管理器</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>挂载&lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt;失败：%2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="157"/>
        <location filename="../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>可移动媒体管理器</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>卸载&lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt;失败：%2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>没有可用设备</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-mount/translations/mount_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>可移动媒体管理器</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>可移动媒体设置</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="26"/>
        <source>When a device is connected:</source>
        <translation>连接设备时：</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>弹出菜单</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>显示信息</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>什么都不做</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt; 已连接。</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt; 已移除。</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>可移动媒体管理器</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>挂载&lt;b&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/b&gt;失败：%2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="157"/>
        <location filename="../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>可移动媒体管理器</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>卸载&lt;strong&gt;&lt;nobr&gt;“%1”&lt;/nobr&gt;&lt;/strong&gt;失败：%2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>没有可用设备</translation>
    </message>
</context>
</TS>
